@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.62 2003/12/01 17:39:52 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.69 2004/02/09 15:56:45 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -86,12 +86,12 @@ char *mstrs[] = {              /* Mode titles to be added to the titlebar. */
 
 
 char *ttype_str[] = {          /* Strings for each trig type value. */
-    N_("De_grees"), N_("Gr_adients"), N_("_Radians")
+    N_("De_grees"), N_("Gr_adians"), N_("_Radians")
 };
 
 char *ttype_desc[] = {         /* Tooltips for each trig type value. */
     N_("Set trigonometric type to degrees"), 
-    N_("Set trigonometric type to gradients"), 
+    N_("Set trigonometric type to gradians"), 
     N_("Set trigonometric type to radians")
 };
 
@@ -434,7 +434,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     do_immed
 },
 {
-    N_("x<sup><i>2</i></sup>"),
+    N_("<i>x</i><sup>2</sup>"),
     N_("Square"),
     NULL,
     { GDK_SHIFT_MASK, 0 },
@@ -790,9 +790,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_immed
 },       
 {        
-    N_("y<sup><i>x</i></sup>"),
-    N_("y to the power of displayed value"),
-    N_("Y to the x"),
+    N_("<i>x</i><sup><i>y</i></sup>"),
+    N_("Raise displayed value to the power of y"),
+    N_("X to the y"),
     { 0, 0 },   
     { GDK_y, 0 },
     'y',
@@ -1017,8 +1017,8 @@ do_calctool(int argc, char **argv)
         }
     }
 
-    v->radix_char = get_radix_char();   /* Locale specific radix character. */
-    v->tsep_char  = get_tsep_char();  /* Locale specific thousands seperator. */
+    v->radix = get_radix();    /* Locale specific radix string. */
+    v->tsep  = get_tsep();     /* Locale specific thousands seperator. */
 
     init_text();               /* Setup text strings depending upon language. */
     init_vars();               /* Setup default values for variables. */
@@ -1049,7 +1049,7 @@ do_calctool(int argc, char **argv)
         }
     }
 
-    SPRINTF(title, "%s [%s]", v->tool_label, _(mstrs[(int) v->modetype]));
+    SPRINTF(title, "%s- %s", v->tool_label, _(mstrs[(int) v->modetype]));
     set_title(FCP_KEY, title);
 
     show_display(v->MPdisp_val);     /* Output in correct display mode. */
