@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.41 2003/10/02 19:16:16 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.48 2004/02/04 00:00:12 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -47,7 +47,7 @@
 
 /* Menu bar menu types. */
 enum mb_type { M_ABOUT, M_ASCII, M_BASIC, M_CONTENTS, M_COPY,  M_FIN,
-               M_PASTE, M_QUIT,  M_REGS,  M_SCI,      M_ZEROES };
+               M_PASTE, M_QUIT,  M_REGS,  M_SCI,      M_TSEP,  M_ZEROES };
 
 enum base_type { BIN, OCT, DEC, HEX };      /* Base definitions. */
 
@@ -69,7 +69,7 @@ enum num_type { ENG, FIX, SCI };            /* Number display mode. */
 
 /* Resources. */
 enum res_type { R_ACCURACY, R_BASE, R_DISPLAY, R_MODE, R_REGS, R_TRIG,
-                R_ZEROES
+                R_ZEROES,   R_TSEP
 };
 
 enum trig_type { DEG, GRAD, RAD };          /* Trigonometric types. */
@@ -159,6 +159,7 @@ enum trig_type { DEG, GRAD, RAD };          /* Trigonometric types. */
 #endif /*LINT_CAST*/
 
 #define MAX_DIGITS     40         /* Maximum displayable number of digits. */
+#define MAX_BUFFER     (MAX_DIGITS + MAX_DIGITS / 3 * MB_LEN_MAX + 1)
 
 /* Maximum number of various graphics pieces. */
 #define MAXITEMS       8          /* Maximum number of panel items. */
@@ -235,7 +236,7 @@ struct calcVars {                      /* Calctool variables and options. */
     char con_names[MAXREGS][MAXLINE];  /* Selectable constant names. */
     char display[MAXLINE];             /* Current calculator display. */
     char *exp_posn;                    /* Position of the exponent sign. */
-    char fnum[MAX_DIGITS+1];           /* Scratchpad for fixed numbers. */
+    char fnum[MAX_BUFFER];             /* Scratchpad for fixed numbers. */
     char fun_names[MAXREGS][MAXLINE];  /* Function names from .gcalctoolcf. */
     char fun_vals[MAXREGS][MAXLINE];   /* Function defs from .gcalctoolcf. */
     char *home;                        /* Pathname for users home directory. */
@@ -244,9 +245,11 @@ struct calcVars {                      /* Calctool variables and options. */
     char opstr[5];                     /* Operand string during pending op. */
     char *progname;                    /* Name of this program. */
     char pstr[5];                      /* Current button text string. */
-    char radix_char;                   /* Locale specific radix character. */
+    const char *radix;                 /* Locale specific radix string. */
     char *shelf;                       /* PUT selection shelf contents. */
-    char snum[MAX_DIGITS+1];           /* Scratchpad for scientific numbers. */
+    char snum[MAX_BUFFER];             /* Scratchpad for scientific numbers. */
+    char tnum[MAX_BUFFER];             /* Scratchpad for tsep numbers. */
+    const char *tsep;                /* Locale specific thousands seperator. */
     char *titleline;                   /* Value of titleline (if present). */
     char *tool_label;                  /* Title line for calculator window. */
 
@@ -290,6 +293,7 @@ struct calcVars {                      /* Calctool variables and options. */
     int pointed;       /* Whether a decimal point has been given. */
     int rstate;        /* Indicates if memory register frame is displayed. */
     int show_paren;    /* Set if we wish to show DISPLAYITEM during parens. */
+    int show_tsep;     /* Set if the thousands seperator should be shown. */
     int show_zeroes;   /* Set if trailing zeroes should be shown. */
     int started;       /* Set just before window is displayed. */
     int toclear;       /* Indicates if display should be cleared. */
@@ -312,8 +316,9 @@ struct button *copy_button_info(struct button *);
 
 char *button_str(int);
 char *convert(char *);
-char get_numeric_sep();
+const char *get_radix();
 char *get_resource(enum res_type);
+const char *get_tsep();
 char *make_number(int *, int, BOOLEAN, BOOLEAN);
 char *set_bool(int);
 
@@ -326,6 +331,8 @@ int get_menu_entry(enum menu_type, int);
 int key_equal(struct button *, struct button);
 int main(int, char **);
 
+void adjust_radix(char *);
+void add_tsep();
 void beep();
 void clear_display(int);
 void display_prop_sheet();
@@ -369,7 +376,7 @@ void make_frames();
 void make_menus();
 void make_reg(int, char *);
 void make_registers();
-void MPstr_to_num(char *, enum base_type, int *);
+void MPstr_to_num(char *, enum base_type, gboolean, int *);
 void paren_disp(char);
 void process_item(struct button *);
 void process_stack(int, int, int);
@@ -380,6 +387,7 @@ void put_resource(enum res_type, char *);
 void read_cfdefs();
 void read_resources();
 void read_str(char **, char *);
+void remove_tsep(char *);
 void save_pending_values(struct button *);
 void save_resources();
 void set_accuracy_toggle(int);
